pub struct ProtoBatchSerializer { /* private fields */ }Expand description
Protobuf batch serializer that encodes each event into individual protobuf bytes.
Implementations
Sourceimpl ProtoBatchSerializer
impl ProtoBatchSerializer
Sourcepub fn new(config: ProtoBatchSerializerConfig) -> Result<Self, Error>
pub fn new(config: ProtoBatchSerializerConfig) -> Result<Self, Error>
Create a new ProtoBatchSerializer with the given configuration.
Sourcepub fn encode_batch(
&self,
events: &[Event],
) -> Result<Vec<Vec<u8>>, ProtoBatchEncodingError>
pub fn encode_batch( &self, events: &[Event], ) -> Result<Vec<Vec<u8>>, ProtoBatchEncodingError>
Encode a batch of events into individual protobuf byte buffers.